@@ -1,7 +1,7 @@
 import math
 
 
-def SimpleConsoleMenu(menuName,menuItems,inputQuestion,autoAddQuit = False,onlyReturnNumber = True, allowedCharacters = '', acceptedQuitCharacters = ''):
+def SimpleConsoleMenu(menuName,menuItems,inputQuestion,menuSize = 76,autoAddQuit = False,onlyReturnNumber = True, allowedCharacters = '', acceptedQuitCharacters = ''):
     """
     Makes a menu
 
@@ -9,6 +9,7 @@ def SimpleConsoleMenu(menuName,menuItems,inputQuestion,autoAddQuit = False,onlyR
         menuName               - Required  : name of the menu (Str)
         menuItems              - Required  : menu items, separated with ';' (Str)
         inputQuestion          - Required  : Question input (Str)
+        menuSize               - Optional  : Size of the menu (Int)
         autoAddQuit            - Optional  : automatically add a quit option (Bool)
         onlyReturnNumber       - Optional  : only numbers are allowed to return (Bool)
         allowedCharacters      - Optional  : specifier which character(s) are allowed if onlyReturnNumber is False, separated with ';' (str)
@@ -26,7 +27,7 @@ def SimpleConsoleMenu(menuName,menuItems,inputQuestion,autoAddQuit = False,onlyR
     menuNumber = 1
     chooseAmount = 0
     menuNameLength = len(menuName) + 2
-    menuNameLength = 76 - menuNameLength
+    menuNameLength = menuSize - menuNameLength
     menuNameLength /= 2
     if (menuNameLength % 2) == 0:
         #even
@@ -39,7 +40,7 @@ def SimpleConsoleMenu(menuName,menuItems,inputQuestion,autoAddQuit = False,onlyR
     for x in menuItemsList:
         print(f'{menuNumber}. {x}')
         menuNumber += 1
-    print(76*'-')
+    print(menuSize*'-')
     while chooseLoop:
         choose = input(inputQuestion)
         if onlyReturnNumber:
@@ -83,7 +84,7 @@ def SimpleConsoleMenu(menuName,menuItems,inputQuestion,autoAddQuit = False,onlyR
             return choose
 
 
-def SimpleConsoleMenuBlock(menuName,menuItems,inputQuestion,autoAddQuit = False,onlyReturnNumber = True, allowedCharacters = '', acceptedQuitCharacters = ''):
+def SimpleConsoleMenuBlock(menuName,menuItems,inputQuestion,menuSize = 76,autoAddQuit = False,onlyReturnNumber = True, allowedCharacters = '', acceptedQuitCharacters = ''):
     """
     Makes a menu with a box arround it
 
@@ -91,6 +92,7 @@ def SimpleConsoleMenuBlock(menuName,menuItems,inputQuestion,autoAddQuit = False,
         menuName               - Required  : name of the menu (Str)
         menuItems              - Required  : menu items, separated with ';' (Str)
         inputQuestion          - Required  : Question input (Str)
+        menuSize               - Optional  : Size of the menu (Int)
         autoAddQuit            - Optional  : automatically add a quit option (Bool)
         onlyReturnNumber       - Optional  : only numbers are allowed to return (Bool)
         allowedCharacters      - Optional  : specifier which character(s) are allowed if onlyReturnNumber is False, separated with ';' (str)
@@ -108,7 +110,7 @@ def SimpleConsoleMenuBlock(menuName,menuItems,inputQuestion,autoAddQuit = False,
     menuNumber = 1
     chooseAmount = 0
     menuNameLength = len(menuName) + 2
-    menuNameLength = 76 - menuNameLength
+    menuNameLength = menuSize - menuNameLength
     menuNameLength /= 2
     if (menuNameLength % 2) == 0:
         print('╭'+int(menuNameLength-1)*'─',menuName,int(menuNameLength-1)*'─'+'╮')
@@ -118,9 +120,9 @@ def SimpleConsoleMenuBlock(menuName,menuItems,inputQuestion,autoAddQuit = False,
         print('╭'+int(menuNameLength1-1)*'─',menuName,int(menuNameLength2-1)*'─'+'╮')
     for x in menuItemsList:
         menuItemsWithNumbers = str(menuNumber)+'. '+x
-        print(f'│{menuItemsWithNumbers}'+(74-len(menuItemsWithNumbers))*' '+'│')
+        print(f'│{menuItemsWithNumbers}'+((menuSize-2)-len(menuItemsWithNumbers))*' '+'│')
         menuNumber += 1
-    print('╰'+74*'─'+'╯')
+    print('╰'+(menuSize-2)*'─'+'╯')
     while chooseLoop:
         choose = input(inputQuestion)
         if onlyReturnNumber:
@@ -160,12 +162,12 @@ def SimpleConsoleMenuBlock(menuName,menuItems,inputQuestion,autoAddQuit = False,
         else:
             return choose
 
-# print(SimpleConsoleMenuBlock('menu','item1;item2;item3;item4;item5','Number:',True,True))
+# print(SimpleConsoleMenuBlock('menu','item1;item2;item3;item4;item5','Number:',20,True,True))
 
 # ╭─────────────╮
 # │    lorem    │
 # │    ipsum    │
 # │    dolor    │
 # ╰─────────────╯
-# print(SimpleConsoleMenu('menu','item1;item2','Number:',True,False,'a;b','c'))
+# print(SimpleConsoleMenu('menu','item1;item2','Number:',20,True,False,'a;b','c'))
                     
\ No newline at end of file
